@@ -840,6 +840,18 @@ proc UpdateColormapLevel {} {
     }
 }
 
+proc UpdateColormapLevelFrame {frame} {
+    global icolorbar
+
+    global debug
+    if {$debug(tcl,update)} {
+	puts stderr "UpdateColormapLevelFrame $frame"
+    }
+
+    set cb ${frame}cb
+    $cb colormap level [$frame get colormap level $icolorbar(num)]
+}
+
 proc UpdateColormapLevelMosaic {which x y sys} {
     global icolorbar
 
@@ -1027,27 +1039,27 @@ proc ColormapDialog {} {
     $mb add cascade -label [msgcat::mc {Color}] -menu $mb.color
 
     ThemeMenu $mb.file
-    $mb.file add command -label "[msgcat::mc {Open}]..." \
+    $mb.file add command -label [msgcat::mc {Open}] \
 	-command LoadColormap -accelerator "${ds9(ctrl)}O"
-    $mb.file add command -label "[msgcat::mc {Save}]..." \
+    $mb.file add command -label [msgcat::mc {Save}] \
 	-command SaveColormap -accelerator "${ds9(ctrl)}S"
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Apply}] \
 	-command ApplyColormap
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Download Colormap}]..." \
+    $mb.file add command -label [msgcat::mc {Download Colormap}] \
 	-command {HV cpt CPT-CITY http://soliton.vm.bytemark.co.uk/pub/cpt-city}
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load Contrast/Bias}]..."\
+    $mb.file add command -label [msgcat::mc {Load Contrast/Bias}]\
 	-command LoadContrastBias
-    $mb.file add command -label "[msgcat::mc {Save Contrast/Bias}]..." \
+    $mb.file add command -label [msgcat::mc {Save Contrast/Bias}] \
 	-command SaveContrastBias
     $mb.file add separator
-    $mb.file add command -label "[msgcat::mc {Load Color Tags}]..."\
+    $mb.file add command -label [msgcat::mc {Load Color Tags}]\
 	-command OpenColorTag
-    $mb.file add command -label "[msgcat::mc {Save Color Tags}]..." \
+    $mb.file add command -label [msgcat::mc {Save Color Tags}] \
 	-command SaveColorTag
-    $mb.file add command -label "[msgcat::mc {Delete Color Tags}]..." \
+    $mb.file add command -label [msgcat::mc {Delete Color Tags}] \
 	-command DeleteColorTag
     $mb.file add separator
     $mb.file add command -label [msgcat::mc {Close}] \
@@ -1231,9 +1243,9 @@ proc UpdateColorDialog {} {
 		base -
 		3d {
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Open}]..." -state normal
+			[msgcat::mc {Open}] -state normal
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Save}]..." -state normal
+			[msgcat::mc {Save}] -state normal
 
 		    foreach cmap $icolorbar(default,cmaps) {
 			$icolorbar(mb).colormap entryconfig $cmap -state normal
@@ -1255,12 +1267,13 @@ proc UpdateColorDialog {} {
 		}
 		rgb {
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Open}]..." -state disabled
+			[msgcat::mc {Open}] -state disabled
 		    $icolorbar(mb).file entryconfig \
-			"[msgcat::mc {Save}]..." -state disabled
+			[msgcat::mc {Save}] -state disabled
 
 		    foreach cmap $icolorbar(default,cmaps) {
-			$icolorbar(mb).colormap entryconfig $cmap -state disabled
+			$icolorbar(mb).colormap entryconfig $cmap \
+			    -state disabled
 		    }
 
 		    $icolorbar(mb).colormap entryconfig \
@@ -1279,9 +1292,9 @@ proc UpdateColorDialog {} {
 	    }
 	} else {
 	    $icolorbar(mb).file entryconfig \
-		"[msgcat::mc {Open}]..." -state normal
+		[msgcat::mc {Open}] -state normal
 	    $icolorbar(mb).file entryconfig \
-		"[msgcat::mc {Save}]..." -state normal
+		[msgcat::mc {Save}] -state normal
 
 	    foreach cmap $icolorbar(default,cmaps) {
 		$icolorbar(mb).colormap entryconfig $cmap -state normal
@@ -1324,8 +1337,8 @@ proc LayoutColorbarAdjust {} {
 	set colorbar(horizontal,height) [expr $colorbar(size) + $ytl + $ysp]
 
 	# vertical width
-	# 6 chars
-	set xstr [font measure $ff "000000"]
+	# 9 chars
+	set xstr [font measure $ff "000000000"]
 	set xtl [$ds9(canvas) itemcget colorbar -ticks]
 	set colorbar(vertical,width) [expr $colorbar(size) + $xtl + $xstr]
     } else {
