@@ -58,6 +58,7 @@ proc CommSet {fn paramlist {safemode 0}} {
 	dssstsci {ProcessSTSCICmd param i}
 	envi {ProcessENVICmd param i {} $fn}
 	export {ProcessExportCmd param i}
+	fade {ProcessFadeCmd param i}
 	file {ProcessFileCmd param i {} {} {}}
 	fits {ProcessFitsCmd param i {} $fn}
 	frame {ProcessFrameCmd param i}
@@ -72,6 +73,7 @@ proc CommSet {fn paramlist {safemode 0}} {
 	iexam -
 	imexam {}
 	iis {ProcessIISCmd param i}
+	illustrate {ProcessIllustrateCmd param i {} $fn}
 	jpg -
 	jpeg {ProcessJPEGCmd param i {} $fn}
 	lock {ProcessLockCmd param i}
@@ -269,6 +271,7 @@ proc CommGet {proc id paramlist fn} {
 	envi {}
 	exit {}
 	export {}
+	fade {ProcessSendFadeCmd $proc $id $param}
 	file {ProcessSendFileCmd $proc $id $param}
 	fits {ProcessSendFitsCmd $proc $id $param {} $fn}
 	frame {ProcessSendFrameCmd $proc $id $param}
@@ -283,6 +286,7 @@ proc CommGet {proc id paramlist fn} {
 	iexam -
 	imexam {ProcessSendIExamCmd $proc $id $param}
 	iis {ProcessSendIISCmd $proc $id $param}
+	illustrate {ProcessSendIllustrateCmd $proc $id $param}
 	jpg -
 	jpeg {ProcessSendJPEGCmd $proc $id $param {} $fn}
 	lock {ProcessSendLockCmd $proc $id $param}
