@@ -139,6 +139,12 @@ proc ProcessCommand {argv argc} {
 	    -analysis {incr i; ProcessAnalysisCmd argv i {} {}}
 	    -array {set file(type) array}
 	    -asinh {set scale(type) asinh; ChangeScale}
+	    -advance -
+	    -advanced {
+		#backward compatibility
+		set view(layout) advanced
+		LayoutView
+	    }
 	    -bg -
 	    -background {
 		# backward compatibility prefs
@@ -146,6 +152,11 @@ proc ProcessCommand {argv argc} {
 		ProcessBgCmd argv i
 	    }
 	    -backup {incr i; ProcessBackupCmd argv i}
+	    -basic {
+		#backward compatibility
+		set view(layout) basic
+		LayoutView
+	    }
 	    -bin {incr i; ProcessBinCmd argv i}
 	    -block {incr i; ProcessBlockCmd argv i}
 	    -blink {incr i; ProcessBlinkCmd argv i}
@@ -173,6 +184,7 @@ proc ProcessCommand {argv argc} {
 	    -export {incr i; ProcessExportCmd argv i}
 	    -exit -
 	    -quit {ProcessQuitCmd argv i}
+	    -fade {incr i; ProcessFadeCmd argv i}
 	    -frame {incr i; ProcessFrameCmd argv i}
 	    -fifo {
 		incr i
@@ -221,6 +233,7 @@ proc ProcessCommand {argv argc} {
 	    }
 	    -iconify {incr i; ProcessIconifyCmd argv i}
 	    -iis {incr i; ProcessIISCmd argv i}
+	    -illustrate {incr i; ProcessIllustrateCmd argv i {} {}}
 	    -info {
 		# backward compatibility
 		set view(info) 1
