@@ -14,22 +14,24 @@ proc Toplevel {w mb style title proc} {
     wm group $w $ds9(top)
     wm protocol $w WM_DELETE_WINDOW $proc
 
-    # we need this first, before the configure command
-    ThemeMenu $mb
+    if {$mb != {}} {
+	# we need this first, before the configure command
+	ThemeMenu $mb
 
-    switch $ds9(wm) {
-	x11 -
-	win32 {}
-	aqua {
-	    AppleMenu $mb
-	    switch $style {
-		6 {::tk::unsupported::MacWindowStyle style $w document "closeBox collapseBox"}
-		7 {::tk::unsupported::MacWindowStyle style $w document "closeBox fullZoom collapseBox resizable"}
+	switch $ds9(wm) {
+	    x11 -
+	    win32 {}
+	    aqua {
+		AppleMenu $mb
+		switch $style {
+		    6 {::tk::unsupported::MacWindowStyle style $w document "closeBox collapseBox"}
+		    7 {::tk::unsupported::MacWindowStyle style $w document "closeBox fullZoom collapseBox resizable"}
+		}
 	    }
 	}
-    }
 
-    $w configure -menu $mb
+	$w configure -menu $mb
+    }
 
     DialogCenter $w
 }
@@ -50,7 +52,7 @@ proc DialogCreate {w title varname} {
     wm iconname $w "$title"
 
     upvar #0 varname var
-    wm protocol $w WM_DELETE_WINDOW "set $varname 1"
+    wm protocol $w WM_DELETE_WINDOW [list set $varname 1]
 
     DialogCenter $w
 }
@@ -77,7 +79,11 @@ proc DialogWait {w varname {focus {}}} {
     catch {grab $w}
     tkwait variable $varname
     catch {grab release $w}
-    focus $old
+
+    # parent window may have been closed
+    if {[winfo exists $old]} {
+	focus $old
+    }
 
     # reset errorInfo
     global errorInfo
