@@ -1,4 +1,4 @@
-#  Copyright (C) 1999-2018
+#  Copyright (C) 1999-2021
 #  Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 #  For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -38,7 +38,7 @@ proc LoadFitsFile {fn layer mode} {
 	set reg "${base}\[REGION\]"
 	if {[$current(frame) fitsy has ext "\"$reg\""]} {
 	    RealizeDS9
-	    catch {$current(frame) marker load fits "\"$reg\"" $marker(default,color)}
+	    catch {$current(frame) marker load fits "\"$reg\"" $marker(color)}
 	}
     }
 }
@@ -115,7 +115,7 @@ proc ProcessFitsCmd {varname iname sock fn} {
 
 proc FitsCmdLoad {param layer mode} {
     global parse
-    
+
     if {$parse(sock) != {}} {
 	# xpa
 	if {![LoadFitsSocket $parse(sock) $param $layer $mode]} {
