@@ -24,7 +24,6 @@ proc CreateNamedFrame {type} {
     global ds9
 
     CreateNameNumberFrame "Frame$ds9(seq)" $type
-    incr ds9(seq)
 }
 
 proc CreateGotoFrame {num type} {
@@ -33,8 +32,12 @@ proc CreateGotoFrame {num type} {
 
     set which "Frame$num"
     if {[lsearch $ds9(frames) $which]==-1} {
+	set sav $ds9(seq)
+	set ds9(seq) $num
 	CreateNameNumberFrame $which $type
-	set ds9(seq) [expr $num+1]
+	if {$ds9(seq) < $sav} {
+	    set ds9(seq) [expr $sav+1]
+	}
     } else {
 	if {$active($which)==0} {
 	    set active($which) 1
@@ -233,11 +236,13 @@ proc CreateNameNumberFrame {which type} {
     # enable events
     BindEventsFrame $which
     
-    switch $current(mode) {
+    switch -- $current(mode) {
 	crosshair {$which crosshair on}
     }
 
+    # menus
     UpdateFrameMenuItems
+    UpdateRegionMenu
 
     # update frame colormap
     $which colormap [${which}cb get colormap]
@@ -246,6 +251,9 @@ proc CreateNameNumberFrame {which type} {
     set current(frame) $which
     set current(colorbar) ${which}cb
 
+    # next sequence number
+    incr ds9(seq)
+
     DisplayMode
 }
 
@@ -587,7 +595,8 @@ proc EnterFrame {which x y} {
 	colorbar -
 	examine -
 	iexam -
-	3d {}
+	3d -
+	illustrate {}
     }
 
     EnterInfoBox $which
@@ -644,7 +653,8 @@ proc LeaveFrame {which} {
 	    PixelTableClearDialog
 	    HideGraphsData $which
 	}
-	crosshair {}
+	crosshair -
+	illustrate {}
     }
 
     $which magnifier off
@@ -715,7 +725,8 @@ proc DoMotion {which x y cursor1 cursor2} {
 	    UpdatePixelTableDialog $which $x $y canvas
 	    UpdateGraphsData $which $x $y canvas
 	}
-	crosshair {}
+	crosshair -
+	illustrate {}
     }
 
     UpdateMagnifier $which $x $y
@@ -726,14 +737,14 @@ proc Button1Frame {which x y} {
     global current
     global imarker
 
-    global debug
-    if {$debug(tcl,events)} {
-	puts stderr "Button1Frame $which"
-    }
-
     # let others know that the mouse is down
     set ds9(b1) 1
 
+    global debug
+    if {$debug(tcl,events)} {
+	puts stderr "Button1Frame $which $ds9(b1) $ds9(sb1) $ds9(cb1)"
+    }
+
     switch -- $current(mode) {
 	none {
 	    if {$which == $current(frame)} {
@@ -812,7 +823,8 @@ proc Button1Frame {which x y} {
 	iexam {
 	    IExamButton $which $x $y
 	}
-	3d {}
+	3d -
+	illustrate {}
     }
 }
 
@@ -820,14 +832,14 @@ proc ShiftButton1Frame {which x y} {
     global ds9
     global current
 
-    global debug
-    if {$debug(tcl,events)} {
-	puts stderr "ShiftButton1Frame $which"
-    }
-
     # let others know that the mouse is down
     set ds9(sb1) 1
 
+    global debug
+    if {$debug(tcl,events)} {
+	puts stderr "ShiftButton1Frame $which $ds9(b1) $ds9(sb1) $ds9(cb1)"
+    }
+
     switch -- $current(mode) {
 	none {}
 	pointer -
@@ -856,9 +868,10 @@ proc ShiftButton1Frame {which x y} {
                 FPShift $which $x $y
             }
         }
-	examine {}
-	iexam {}
-	3d {}
+	examine -
+	iexam -
+	3d -
+	illustrate {}
     }
 }
 
@@ -899,9 +912,10 @@ proc ControlButton1Frame {which x y} {
 	crop {
 	    Crop3dButton $which $x $y 1
 	}
-	examine {}
-	iexam {}
-	3d {}
+	examine -
+	iexam -
+	3d -
+	illustrate {}
     }
 }
 
@@ -942,7 +956,8 @@ proc ControlShiftButton1Frame {which x y} {
 	crop -
 	examine -
 	iexam -
-	3d {}
+	3d -
+	illustrate {}
     }
 }
 
@@ -1035,6 +1050,7 @@ proc Motion1Frame {which x y} {
 		3DMotion $which $x $y
 	    }
 	}
+	illustrate {}
     }
 
     UpdateMagnifier $which $x $y
@@ -1109,9 +1125,10 @@ proc Release1Frame {which x y} {
                 FPRelease $which $x $y
             }
         }
-	examine {}
-	iexam {}
-	3d {}
+	examine -
+	iexam -
+	3d -
+	illustrate {}
     }
 
     # let others know that the mouse is up
@@ -1152,7 +1169,7 @@ proc Double1Frame {which x y} {
 	3d {
 	    3DDouble $which
 	}
-	    
+	illustrate {}
     }
 }
 
@@ -1178,7 +1195,8 @@ proc DoubleRelease1Frame {which x y} {
 	footprint -
 	examine -
 	iexam -
-	3d {}
+	3d -
+	illustrate {}
     }
 
     UpdateEditMenu
@@ -1291,7 +1309,7 @@ proc MouseWheelFrame {X Y dd} {
 
     set id [$ds9(canvas) find closest $X $Y]
     set which [lindex [$ds9(canvas) gettags $id] 0]
-    if {[string equal -length 5 {Frame} $which]} {
+    if {[regexp {Frame[0-9]+$} $which]} {
 	set orig [$ds9(canvas) coords $which]
 	set x [expr $X-int([lindex $orig 0])]
 	set y [expr $Y-int([lindex $orig 1])]
@@ -1346,13 +1364,13 @@ proc KeyFrame {which K A xx yy} {
 		minus {CubePrev}
 
 		Up -
-		k {$which warp 0 -1}
+		k {WarpCursor $which 0 -1}
 		Down -
-		j {$which warp 0 1}
+		j {WarpCursor $which 0 1}
 		Left -
-		h {$which warp -1 0}
+		h {WarpCursor $which -1 0}
 		Right -
-		l {$which warp 1 0}
+		l {WarpCursor $which 1 0}
 
 		z {Zoom 2 2}
 		Z {Zoom .5 .5}
@@ -1475,6 +1493,7 @@ proc KeyFrame {which K A xx yy} {
 		Z {Zoom .5 .5}
 	    }
 	}
+	illustrate {}
     }
 
     # since most modes do zoom
@@ -1516,6 +1535,7 @@ proc CopyFrame {} {
     switch -- $current(mode) {
 	pointer -
 	region {MarkerCopy}
+	illustrate {IllustrateMenuCopy}
     }
 }
 
@@ -1525,6 +1545,7 @@ proc CutFrame {} {
     switch -- $current(mode) {
 	pointer -
 	region {MarkerCut}
+	illustrate {IllustrateCut}
     }
 }
 
@@ -1534,6 +1555,7 @@ proc PasteFrame {} {
     switch -- $current(mode) {
 	pointer -
 	region {MarkerPaste}
+	illustrate {IllustratePaste}
     }
 }
 
@@ -1543,6 +1565,7 @@ proc UndoFrame {} {
     switch -- $current(mode) {
 	pointer -
 	region {MarkerUndo}
+	illustrate {IllustrateUndo}
     }
 }
 
@@ -1669,6 +1692,9 @@ proc UpdateActiveFrames {} {
 	    set current(frame) [lindex $ds9(active) 0]
 	    set current(colorbar) ${current(frame)}cb
 	}
+    } else {
+	set current(frame) {}
+	set current(colorbar) {}
     }
 
     DisplayMode
@@ -1706,6 +1732,7 @@ proc GotoFrame {which} {
 
 	switch -- $ds9(display) {
 	    blink -
+	    fade -
 	    single {
 		set ff $current(frame)
 		# frame
@@ -1735,12 +1762,14 @@ proc GotoFrame {which} {
 
 	# frame
 	$current(frame) show
-	$ds9(canvas) raise $current(frame)
+	LayoutRaise $current(frame)
+#	$ds9(canvas) raise $current(frame)
 
 	# colorbar
 	if {$view(colorbar)} {
 	    $current(colorbar) show
-	    $ds9(canvas) raise $current(colorbar)
+	    LayoutRaise $current(colorbar)
+#	    $ds9(canvas) raise $current(colorbar)
 	}
 
 	# graphs
@@ -1761,6 +1790,8 @@ proc DisplayMode {} {
     global tile
     global blink
     global iblink
+    global fade
+    global ifade
 
     switch -- $current(display) {
 	single {set ds9(display) $current(display)}
@@ -1774,6 +1805,7 @@ proc DisplayMode {} {
 		}
 	    }
 	}
+	fade -
 	blink {
 	    if {[llength $ds9(active)] > 1} {
 		set ds9(display) $current(display)
@@ -1793,15 +1825,59 @@ proc DisplayMode {} {
 		set iblink(index) -1
 	    }
 
+	    # turn off fade if on
+	    if {$ifade(id)>0} {
+		after cancel $ifade(id)
+		set ifade(id) 0
+		set ifade(index) -1
+		set ifade(alpha) 0
+		if {$current(frame) != {}} {
+		    $current(frame) fade clear
+		}
+	    }
+
 	    LayoutFrames
 	}
 	blink {
+	    # turn off fade if on
+	    if {$ifade(id)>0} {
+		after cancel $ifade(id)
+		set ifade(id) 0
+		set ifade(index) -1
+		set ifade(alpha) 0
+		if {$current(frame) != {}} {
+		    $current(frame) fade clear
+		}
+	    }
+
 	    # ignore if we are already blinking
 	    if {$iblink(id)==0} {
 		LayoutFrames
 		BlinkTimer
 	    }
 	}
+	fade {
+	    # turn off blink if on
+	    if {$iblink(id)>0} {
+		after cancel $iblink(id)
+		set iblink(id) 0
+		set iblink(index) -1
+	    }
+
+	    # ignore if we are already fading
+	    if {$ifade(id)==0} {
+		# this is such a kludge
+		#   we need all the frames released before, so colorScales
+		#   are defined
+		if {$ds9(init)} {
+		    set ds9(display) tile
+		    RealizeDS9
+		    set ds9(display) fade
+		}
+		LayoutFrames
+		FadeTimer
+	    }
+	}
     }
 }
 
@@ -1821,6 +1897,64 @@ proc BlinkTimer {} {
     set iblink(id) [after $blink(interval) BlinkTimer]
 }
 
+proc FadeTimer {} {
+    global fade
+    global ifade
+    global blink
+    global ds9
+    global current
+
+    # set fixed update
+    set fade(step) 25
+
+    if {[llength $ds9(active)] == 0} {
+	return
+    }
+
+    if {$ifade(index) == -1} {
+	# first time
+	set ifade(index) [lsearch $ds9(active) $current(frame)]
+	incr ifade(index)
+	if {$ifade(index) >= [llength $ds9(active)]} {
+	    set ifade(index) 0
+	}
+
+	set ifade(alpha) 0
+    }
+    
+    # fade
+    set next [lindex $ds9(active) $ifade(index)]
+    switch [$next get type] {
+	base -
+	rgb {
+	    $current(frame) fade [$next get] $ifade(alpha)
+	    
+	    # next time thru
+	    set ifade(alpha) [expr $ifade(alpha)+(100.*$fade(step)/($fade(interval)/2.))]
+
+	    if {$ifade(alpha) >= 100} {
+		$current(frame) fade clear
+		GotoFrame [lindex $ds9(active) $ifade(index)]
+
+		# now hold for blink(interval) before fading again
+		set ifade(index) -1
+		set ifade(id) [after $blink(interval) FadeTimer]
+	    } else {
+		set ifade(id) [after $fade(step) FadeTimer]
+	    }
+	}
+	3d {
+	    # just blink
+	    $current(frame) fade clear
+	    GotoFrame [lindex $ds9(active) $ifade(index)]
+
+	    # now hold for blink(interval) before fading again
+	    set ifade(index) -1
+	    set ifade(id) [after $blink(interval) FadeTimer]
+	}
+    }
+}
+
 proc ResetCurrentFrame {} {
     global current
 
@@ -1940,6 +2074,7 @@ proc FrameToFront {} {
 
     switch -- $ds9(display) {
 	single -
+	fade -
 	blink {}
 	tile {$current(frame) highlite on}
     }
@@ -2194,6 +2329,44 @@ proc BlinkSendCmdInterval {} {
     $parse(proc) $parse(id) "[expr $blink(interval)/1000.]\n"
 }
 
+proc ProcessFadeCmd {varname iname} {
+    upvar $varname var
+    upvar $iname i
+
+    fade::YY_FLUSH_BUFFER
+    fade::yy_scan_string [lrange $var $i end]
+    fade::yyparse
+    incr i [expr $fade::yycnt-1]
+}
+
+proc ProcessSendFadeCmd {proc id param {sock {}} {fn {}}} {
+    global parse
+    set parse(proc) $proc
+    set parse(id) $id
+
+    fadesend::YY_FLUSH_BUFFER
+    fadesend::yy_scan_string $param
+    fadesend::yyparse
+}
+
+proc FadeSendCmd {} {
+    global parse
+    global current
+    
+    if {$current(display)=="fade"} {
+	$parse(proc) $parse(id) "yes\n"
+    } else {
+	$parse(proc) $parse(id) "no\n"
+    }
+}
+
+proc FadeSendCmdInterval {} {
+    global parse
+    global fade
+
+    $parse(proc) $parse(id) "[expr $fade(interval)/1000.]\n"
+}
+
 proc ProcessLockCmd {varname iname} {
     upvar $varname var
     upvar $iname i
