@@ -80,7 +80,8 @@ proc GraphsCreate {frame} {
 	-min 1 -max $igraph(y,max)
     
     $horz element create line1 -xdata $xv -ydata $yv \
-	-symbol none -color [ThemeTreeForeground]
+	-symbol none -color [ThemeTreeForeground] \
+	-mapy y2
 
     # blt graph
     set ${varname}(horz) $horz
@@ -556,7 +557,7 @@ proc MotionGraph {frame xx yy which} {
 	return
     }
 
-    switch $current(mode) {
+    switch -- $current(mode) {
 	crosshair -
 	analysis {
 	    set coord [$frame get crosshair canvas]
@@ -727,7 +728,10 @@ proc UpdateGraphAxisX {frame which} {
     set gr [subst $${varname}($which)]
 
     if {[$frame has fits]} {
-	set xmax [$ds9(canvas) itemcget $frame -width]
+	switch $which {
+	    horz {set xmax [$ds9(canvas) itemcget $frame -width]}
+	    vert {set xmax [$ds9(canvas) itemcget $frame -height]}
+	}
 	$gr xaxis configure -min 0 -max $xmax
 	$gr x2axis configure -min 0 -max $xmax
     } else {
@@ -767,7 +771,8 @@ proc UpdateGraphAxisY {frame which} {
 
 	switch $graph(method) {
 	    sum {set ymax [expr $ymax*$graph(thick)]}
-	    average {}
+	    average -
+	    median {}
 	}
 
 	$gr yaxis configure -min $ymin -max $ymax
@@ -905,6 +910,9 @@ proc GraphDialog {} {
     Toplevel $w $mb 6 [msgcat::mc {Graph Parameters}] GraphDestroyDialog
     $mb add cascade -label [msgcat::mc {File}] -menu $mb.file
     $mb add cascade -label [msgcat::mc {Edit}] -menu $mb.edit
+    $mb add cascade -label [msgcat::mc {Axis}] -menu $mb.axis
+    $mb add cascade -label [msgcat::mc {Method}] -menu $mb.method
+    $mb add cascade -label [msgcat::mc {Font}] -menu $mb.font
 
     ThemeMenu $mb.file
     $mb.file add command -label [msgcat::mc {Apply}] \
@@ -915,13 +923,40 @@ proc GraphDialog {} {
 
     EditMenu $mb igraph
 
-    set f [ttk::labelframe $w.gr -text [msgcat::mc {graph}] -padding 2]
+    ThemeMenu $mb.axis
+    $mb.axis add radiobutton \
+	-label [msgcat::mc {Linear}] -variable graph(log) \
+	-value 0 -command UpdateGraphsGrid
+    $mb.axis add radiobutton \
+	-label [msgcat::mc {Log}] -variable graph(log) \
+	-value 1 -command UpdateGraphsGrid
 
+    ThemeMenu $mb.method
+    $mb.method add radiobutton \
+	-label [msgcat::mc {Average}] -variable graph(method) \
+	-value average -command UpdateGraphsMethod
+    $mb.method add radiobutton \
+	-label [msgcat::mc {Sum}] -variable graph(method) \
+	-value sum -command UpdateGraphsMethod
+    $mb.method add radiobutton \
+	-label [msgcat::mc {Median}] -variable graph(method) \
+	-value median -command UpdateGraphsMethod
+
+    FontMenu $mb.font \
+	graph font font,size font,weight font,slant UpdateGraphsFont
+
+    # Param
+    set f [ttk::frame $w.param]
+
+    ttk::checkbutton $f.grid -text [msgcat::mc {Grid}] \
+	-variable graph(grid) -command UpdateGraphsGrid
+    ttk::label $f.dummy -width 20
     ttk::label $f.tsize -text [msgcat::mc {Size}]
     ttk::entry $f.size -textvariable graph(size) -width 7
     ttk::label $f.tthick -text [msgcat::mc {Thickness}]
     ttk::entry $f.thick -textvariable graph(thick) -width 7
 
+    grid $f.grid $f.dummy -padx 2 -pady 2 -sticky w
     grid $f.tsize $f.size -padx 2 -pady 2 -sticky w
     grid $f.tthick $f.thick -padx 2 -pady 2 -sticky w
 
@@ -932,10 +967,9 @@ proc GraphDialog {} {
     pack $f.apply $f.close -side left -expand true -padx 2 -pady 4
 
     # Fini
-    grid $w.gr -sticky news
-    grid $w.buttons - -sticky ew
-    grid rowconfigure $w 0 -weight 1
-    grid columnconfigure $w 1 -weight 1
+    ttk::separator $w.sep -orient horizontal
+    pack $w.buttons $w.sep -side bottom -fill x
+    pack $w.param -side top -fill both -expand true
 
     bind $w <<Close>> GraphDestroyDialog
 }
@@ -1004,6 +1038,8 @@ proc PrefsDialogGraph {} {
 	-variable pgraph(method) -value average
     ttk::radiobutton $f.smethod -text [msgcat::mc {Sum}] \
 	-variable pgraph(method) -value sum
+    ttk::radiobutton $f.mmethod -text [msgcat::mc {Median}] \
+	-variable pgraph(method) -value median
     ttk::label $f.tfont -text [msgcat::mc {Font}]
     ttk::label $f.tsize -text [msgcat::mc {Size}]
     ttk::entry $f.size -textvariable pgraph(size) -width 7
@@ -1014,7 +1050,7 @@ proc PrefsDialogGraph {} {
 
     grid $f.grid -padx 2 -pady 2 -sticky w
     grid $f.taxis $f.laxis $f.gaxis -padx 2 -pady 2 -sticky w
-    grid $f.tmethod $f.amethod $f.smethod -padx 2 -pady 2 -sticky w
+    grid $f.tmethod $f.amethod $f.smethod $f.mmethod -padx 2 -pady 2 -sticky w
     grid $f.tfont $f.font -padx 2 -pady 2 -sticky w
     grid $f.tsize $f.size -padx 2 -pady 2 -sticky w
     grid $f.tthick $f.thick -padx 2 -pady 2 -sticky w
