@@ -128,17 +128,17 @@ proc IISMessageCmd {message} {
     RefreshInfoBox $current(frame)
 }
 
-proc IISWritePixelsCmd {which ptr x y dx dy} {
+proc IISWritePixelsCmd {which x y dx dy} {
     global debug
     if {$debug(iis)} {
 #	puts stderr "IISWritePixelsCmd: $which $x $y $dx $dy"
     }
 
-    Frame$which iis set $ptr $x $y $dx $dy
+    Frame$which iis set $x $y $dx $dy
     IISResetTimer $which
 }
 
-proc IISReadPixelsCmd {which ptr x y dx dy} {
+proc IISReadPixelsCmd {which x y dx dy} {
     global current
 
     global debug
@@ -147,9 +147,9 @@ proc IISReadPixelsCmd {which ptr x y dx dy} {
     }
 
     if {$which > 0} {
-	Frame$which get iis $ptr $x $y $dx $dy
+	Frame$which get iis $x $y $dx $dy
     } else {
-	$current(frame) get iis $ptr $x $y $dx $dy
+	$current(frame) get iis $x $y $dx $dy
     }
 #    IISResetTimer $which
 }
@@ -236,7 +236,7 @@ proc IISCursorModeCmd {state} {
 	    }
 	} else {
 	    bind $ds9(canvas) <Key> {}
-	    bind $ds9(canvas) <f> {ToggleBindEvents}
+	    bind $ds9(canvas) <f> {ToggleFreeze}
 	    BindEventsFrameKey $which
 
 	    set icursor(timer,abort) 1
@@ -333,15 +333,15 @@ proc IISCursorKey {sym key xx yy} {
     set iis(y) $yy
 
     switch -- $sym {
-	Up {$which warp 0 -1}
-	Down {$which warp 0 1}
-	Left {$which warp -1 0}
-	Right {$which warp 1 0}
+	Up {WarpCursor $which 0 -1}
+	Down {WarpCursor $which 0 1}
+	Left {WarpCursor $which -1 0}
+	Right {WarpCursor $which 1 0}
 
 	default {
 	    if {$key!={}} {
 		set num [string range $which end end]
-		set coord [$which get coordinates $xx $yy physical]
+		set coord [$which get coordinates $xx $yy image]
 		if {$coord == {}} {
 		    switch -- $key {
 			: -
