@@ -4,6 +4,14 @@
 
 package provide DS9 1.0
 
+proc CreateHeader {} {
+    global ds9
+
+    # Panel Frame
+    set ds9(header) [ttk::frame $ds9(main).header]
+    set ds9(header,sep) [ttk::separator $ds9(main).sheader -orient horizontal]
+}
+
 proc CanvasDef {} {
     global canvas
     global ds9
@@ -39,9 +47,24 @@ proc BlinkDef {} {
     set iblink(id) 0
     set iblink(index) -1
 
-    set blink(interval) 500
+    set blink(interval) 1000
 
-    array set pblink [array get blink]
+    array set pblink [array get blink]}
+
+proc FadeDef {} {
+    global fade
+    global ifade
+    global pfade
+
+    set ifade(id) 0
+    set ifade(index) -1
+    set ifade(alpha) 0
+
+    set fade(blend) screen
+    set fade(interval) 2000
+    set fade(step) 25
+
+    array set pfade [array get fade]
 }
 
 proc TileDef {} {
@@ -72,6 +95,7 @@ proc ViewDef {} {
     set view(panner) 1
     set view(magnifier) 1
     set view(buttons) 1
+    set view(icons) 1
     set view(colorbar) 1
     set view(graph,horz) 0
     set view(graph,vert) 0
@@ -163,6 +187,14 @@ proc ThemeConfigCanvas {w} {
 proc InitCanvas {} {
     global ds9
 
+    # must wait until now
+    bind $ds9(canvas) <Configure> [list LayoutView]
+    BindEventsCanvas
+}
+
+proc BindEventsCanvas {} {
+    global ds9
+
     # Bindings
     bind $ds9(canvas) <Tab> [list NextFrame]
     bind $ds9(canvas) <Shift-Tab> [list PrevFrame]
@@ -172,7 +204,10 @@ proc InitCanvas {} {
 	win32 {}
     }
 
-    bind $ds9(canvas) <Configure> [list LayoutView]
+    # iis
+    bind $ds9(canvas) <Key> {}
+    # freeze
+    bind $ds9(canvas) <f> {ToggleFreeze}
 
     # keyboard focus
     switch $ds9(wm) {
@@ -209,9 +244,60 @@ proc InitCanvas {} {
 	    bind $ds9(canvas) <Command-ButtonRelease-1> {Release3Canvas %x %y}
 	}
     }
+}
 
+proc UnBindEventsCanvas {} {
+    global ds9
+
+    # Bindings
+    bind $ds9(canvas) <Tab> {}
+    bind $ds9(canvas) <Shift-Tab> {}
+    switch $ds9(wm) {
+	x11 {bind $ds9(canvas) <ISO_Left_Tab> {}}
+	aqua -
+	win32 {}
+    }
+
+    # iis
+    bind $ds9(canvas) <Key> {}
     # freeze
-    bind $ds9(canvas) <f> {ToggleBindEvents}
+    bind $ds9(canvas) <f> {}
+
+    # keyboard focus
+    switch $ds9(wm) {
+	x11 -
+	aqua {
+	    bind $ds9(canvas) <Enter> {}
+	    bind $ds9(canvas) <Leave> {}
+	}
+	win32 {}
+    }
+    switch $ds9(wm) {
+	x11 {}
+	aqua -
+	win32 {bind $ds9(canvas) <MouseWheel> {}}
+    }
+
+    # backward compatible bindings
+    switch $ds9(wm) {
+	x11 -
+	win32 {
+	    bind $ds9(canvas) <Button-3> {}
+	    bind $ds9(canvas) <B3-Motion> {}
+	    bind $ds9(canvas) <ButtonRelease-3> {}
+	} 
+	aqua {
+	    # swap button-2 and button-3 on the mighty mouse
+	    bind $ds9(canvas) <Button-2> {}
+	    bind $ds9(canvas) <B2-Motion> {}
+	    bind $ds9(canvas) <ButtonRelease-2> {}
+
+	    # x11 command key emulation
+	    bind $ds9(canvas) <Command-Button-1> {}
+	    bind $ds9(canvas) <Command-B1-Motion> {}
+	    bind $ds9(canvas) <Command-ButtonRelease-1> {}
+	}
+    }
 }
 
 proc Button3Canvas {x y} {
@@ -258,7 +344,7 @@ proc Release3Canvas {x y} {
     }
 }
 
-proc UnBindEventsCanvas {} {
+proc UnBindEventsCanvasItems {} {
     global ds9
 
     foreach ff $ds9(active) {
@@ -268,7 +354,7 @@ proc UnBindEventsCanvas {} {
     }
 }
 
-proc BindEventsCanvas {} {
+proc BindEventsCanvasItems {} {
     global ds9
 
     foreach ff $ds9(active) {
@@ -278,6 +364,17 @@ proc BindEventsCanvas {} {
     }
 }
 
+proc LayoutRaise {id} {
+    global ds9
+
+    set ll [$ds9(canvas) find withtag {graphic}]
+    if {$ll != {}} {
+	$ds9(canvas) lower $id [lindex $ll 0]
+    } else {
+	$ds9(canvas) raise $id
+    }
+}
+
 proc LayoutView {} {
     global view
 
@@ -286,42 +383,66 @@ proc LayoutView {} {
 	puts stderr "LayoutView"
     }
 
+    LayoutViewInit
     switch $view(layout) {
 	horizontal {LayoutViewHorz}
 	vertical {LayoutViewVert}
+	basic {LayoutViewBasic}
+	advanced {LayoutViewAdvanced}
     }
 
     LayoutInfoPanel
     LayoutButtons
     LayoutFrames
+
+    UpdateViewMenu
+}
+
+proc LayoutViewInit {} {
+    global ds9
+
+    # reset weights
+    grid rowconfigure $ds9(main) 0 -weight 0
+    grid columnconfigure $ds9(main) 0 -weight 0
+    grid rowconfigure $ds9(main) 2 -weight 0
+    grid columnconfigure $ds9(main) 2 -weight 0
+    grid rowconfigure $ds9(main) 4 -weight 0
+    grid columnconfigure $ds9(main) 4 -weight 0
+
+    grid forget $ds9(image)
+    grid forget $ds9(header)
+    grid forget $ds9(header,sep)
+    grid forget $ds9(buttons,frame)
+    grid forget $ds9(buttons,sep)
+    grid forget $ds9(icons,top)
+    grid forget $ds9(icons,top,sep)
+    grid forget $ds9(icons,left)
+    grid forget $ds9(icons,left,sep)
+    grid forget $ds9(icons,bottom)
+    grid forget $ds9(icons,bottom,sep)
+
+    pack forget $ds9(panner)
+    pack forget $ds9(panner,align)
+    pack forget $ds9(panner,center)
+    pack forget $ds9(magnifier)
+    pack forget $ds9(magnifier,plus)
+    pack forget $ds9(magnifier,minus)
+    pack forget $ds9(info)
 }
 
 proc LayoutViewHorz {} {
     global ds9
-    global current
     global view
 
     # ds9(main) weight
     grid rowconfigure $ds9(main) 4 -weight 1
     grid columnconfigure $ds9(main) 0 -weight 1
-    grid rowconfigure $ds9(main) 0 -weight 0
-    grid columnconfigure $ds9(main) 4 -weight 0
-
-    grid forget $ds9(panel)
-    grid forget $ds9(panel,sep)
-    grid forget $ds9(buttons,frame)
-    grid forget $ds9(buttons,sep)
-    grid forget $ds9(image)
-
-    pack forget $ds9(info)
-    pack forget $ds9(magnifier)
-    pack forget $ds9(panner)
 
     # info panel
     if {$view(info) || $view(magnifier) || $view(panner)} {
-	grid $ds9(panel) -row 0 -column 0 -sticky ew -columnspan 3
-	$ds9(panel,sep) configure -orient horizontal
-	grid $ds9(panel,sep) -row 1 -column 0 -sticky ew -columnspan 3
+	grid $ds9(header) -row 0 -column 0 -sticky ew
+	$ds9(header,sep) configure -orient horizontal
+	grid $ds9(header,sep) -row 1 -column 0 -sticky ew
     }
 
     if {$view(info)} {
@@ -353,30 +474,17 @@ proc LayoutViewHorz {} {
 
 proc LayoutViewVert {} {
     global ds9
-    global current
     global view
 
     # ds9(main) weight
-    grid rowconfigure $ds9(main) 4 -weight 0
-    grid columnconfigure $ds9(main) 0 -weight 0
     grid rowconfigure $ds9(main) 0 -weight 1
     grid columnconfigure $ds9(main) 4 -weight 1
 
-    grid forget $ds9(panel)
-    grid forget $ds9(panel,sep)
-    grid forget $ds9(buttons,frame)
-    grid forget $ds9(buttons,sep)
-    grid forget $ds9(image)
-    
-    pack forget $ds9(magnifier)
-    pack forget $ds9(info)
-    pack forget $ds9(panner)
-
     # info panel
     if {$view(info) || $view(magnifier) || $view(panner)} {
-	grid $ds9(panel) -row 0 -column 0 -sticky ns
-	$ds9(panel,sep) configure -orient vertical
-	grid $ds9(panel,sep) -row 0 -column 1 -sticky ns
+	grid $ds9(header) -row 0 -column 0 -sticky ns
+	$ds9(header,sep) configure -orient vertical
+	grid $ds9(header,sep) -row 0 -column 1 -sticky ns
     }
 
     if {$view(magnifier)} {
@@ -405,6 +513,77 @@ proc LayoutViewVert {} {
     grid $ds9(image) -row 0 -column 4 -sticky news
 }
 
+proc LayoutViewBasic {} {
+    global ds9
+    global view
+
+    # ds9(main) weight
+    grid rowconfigure $ds9(main) 0 -weight 1
+    grid columnconfigure $ds9(main) 0 -weight 1
+
+    # image
+    grid $ds9(image) -row 0 -column 0 -sticky news
+}
+
+proc LayoutViewAdvanced {} {
+    global ds9
+    global view
+
+    # ds9(main) weight
+    grid rowconfigure $ds9(main) 2 -weight 1
+    grid columnconfigure $ds9(main) 2 -weight 1
+
+    # info panel
+    if {$view(info) || $view(magnifier) || $view(panner)} {
+	$ds9(header,sep) configure -orient vertical
+	grid $ds9(header,sep) -row 2 -column 3 -sticky ns
+	grid $ds9(header) -row 2 -column 4 -sticky ns
+    }
+
+    if {$view(panner)} {
+	pack $ds9(panner) -side top -padx 2 -pady 2
+	if {$view(icons)} {
+	    pack $ds9(panner,align) -side left
+	    pack $ds9(panner,center) -side left
+	}
+    }
+
+    if {$view(magnifier)} {
+	pack $ds9(magnifier) -side top -padx 2 -pady 2
+	if {$view(icons)} {
+	    pack $ds9(magnifier,minus) -side left
+	    pack $ds9(magnifier,plus) -side left
+	}
+    }
+
+    if {$view(info)} {
+	pack $ds9(info) -side bottom -padx 2 -pady 2 -fill y -expand true
+	if {$view(magnifier)} {
+	    pack $ds9(info) -after $ds9(magnifier)
+	}
+    }
+
+    # buttons
+    if {$view(buttons)} {
+	$ds9(buttons,sep) configure -orient vertical
+	grid $ds9(buttons,sep) -row 2 -column 5 -sticky ns
+	grid $ds9(buttons,frame) -row 2 -column 6 -sticky ns
+    }
+
+    # icons
+    if {$view(icons)} {
+	grid $ds9(icons,top) -row 0 -column 0 -sticky ew -columnspan 7
+	grid $ds9(icons,top,sep) -row 1 -column 0 -sticky ew -columnspan 7
+	grid $ds9(icons,left) -row 2 -column 0 -sticky ns
+	grid $ds9(icons,left,sep) -row 2 -column 1 -sticky ns
+	grid $ds9(icons,bottom,sep) -row 3 -column 0 -sticky ew -columnspan 7
+	grid $ds9(icons,bottom) -row 4 -column 0 -sticky ew -columnspan 7
+    }
+    
+    # image
+    grid $ds9(image) -row 2 -column 2 -sticky news
+}
+
 proc LayoutFrames {} {
     global ds9
     global current
@@ -485,7 +664,8 @@ proc LayoutFramesNone {} {
     if {$view(colorbar)} {
 	if {[LayoutColorbar colorbar 0 0 [winfo width $ds9(canvas)] [winfo height $ds9(canvas)]]} {
 	    colorbar show
-	    $ds9(canvas) raise colorbar
+	    LayoutRaise colorbar
+#	    $ds9(canvas) raise colorbar
 	}
     }
     
@@ -510,9 +690,9 @@ proc LayoutFramesOneOrMore {} {
     global view
 
     switch -- $ds9(display) {
-	single {
-	    LayoutFrameOne
-	}
+	fade -
+	blink -
+	single {LayoutFrameOne}
 	tile {
 	    if {[llength $ds9(active)] > 1} {
 		if {$view(multi)} {
@@ -524,9 +704,6 @@ proc LayoutFramesOneOrMore {} {
 		LayoutFrameOne
 	    }
 	}
-	blink {
-	    LayoutFrameOne
-	}
     }
 }
 
@@ -565,12 +742,14 @@ proc LayoutFrameOne {} {
 
     # frame
     $current(frame) show
-    $ds9(canvas) raise $current(frame)
+    LayoutRaise $current(frame)
+#    $ds9(canvas) raise $current(frame)
 
     # colorbar
     if {$view(colorbar)} {
 	$current(colorbar) show
-	$ds9(canvas) raise $current(colorbar)
+	LayoutRaise $current(colorbar)
+#	$ds9(canvas) raise $current(colorbar)
     }
 
     # graphs
@@ -676,13 +855,15 @@ proc TileRect {numx numy} {
 	LayoutFrameAdjust fw fh
 	$ff configure -x $xx($ii) -y $yy($ii) -width $fw -height $fh -anchor nw
 	$ff show
-	$ds9(canvas) raise $ff
+	LayoutRaise $ff
+#	$ds9(canvas) raise $ff
 
 	# colorbar
 	if {$view(colorbar)} {
 	    LayoutColorbar ${ff}cb $xx($ii) $yy($ii) $ww $hh
 	    ${ff}cb show
-	    $ds9(canvas) raise ${ff}cb
+	    LayoutRaise ${ff}cb
+#	    $ds9(canvas) raise ${ff}cb
 	}
 
 	# graphs
@@ -746,7 +927,8 @@ proc TileRectNone {numx numy} {
 	    $ff configure -x $xx($ii) -y $yy($ii) \
 		-width $ww -height $hh -anchor nw
 	    $ff show
-	    $ds9(canvas) raise $ff
+	    LayoutRaise $ff
+#	    $ds9(canvas) raise $ff
 	}
 
 	if {$view(colorbar)} {
@@ -775,7 +957,8 @@ proc TileRectNone {numx numy} {
     # colorbar
     if {$view(colorbar)} {
 	${ff}cb show
-	$ds9(canvas) raise ${ff}cb
+	LayoutRaise ${ff}cb
+#	$ds9(canvas) raise ${ff}cb
     }
 
     # graphs
