@@ -27,12 +27,14 @@ proc MarkerDef {} {
     set marker(centroid,auto) 0
     set marker(centroid,iteration) 30
     set marker(centroid,radius) 10
+
     set marker(shape) circle
     set marker(color) green
+    set marker(fill) 0
     set marker(color,default) 0
-    set marker(dashlist) {8 3}
     set marker(width) 1
     set marker(dash) 0
+
     set marker(fixed) 0
     set marker(edit) 1
     set marker(move) 1
@@ -58,7 +60,6 @@ proc MarkerDef {} {
 
     set marker(copy) {}
     set marker(copy,system) {}
-    set marker(maxdialog) 48
     set marker(load) current
 
     set marker(system) physical
@@ -280,8 +281,9 @@ proc MarkerCursor {which x y handleCursor overCursor} {
 
 proc MarkerArrowKey {which x y} {
     global current
+    global ds9
 
-    $which warp $x $y
+    WarpCursor $which $x $y
     $which marker $current(mode) move $x $y
 }
 
@@ -509,7 +511,7 @@ proc MarkerRelease {which x y} {
 	    # determine if this is an accident and just create the default
 	    set diffx [expr $x-$imarker(x)]
 	    set diffy [expr $y-$imarker(y)]
-	    if {[expr sqrt($diffx*$diffx + $diffy*$diffy)]<2} {
+	    if {[expr sqrt($diffx*$diffx + $diffy*$diffy)]<4} {
 		MarkerDefault $which
 	    }
 
@@ -644,19 +646,11 @@ proc MarkerCreateShape {which x y} {
 	polygon {append cmd " .001 .001"}
 	line {append cmd " $x $y"}
 	vector {append cmd " $x $y"}
-	projection {append cmd " $x $y $pmarker(projection,thick) "}
+	projection {append cmd " $x $y $pmarker(projection,thick)"}
 	segment {append cmd " .001 .001"}
-	text {
-	    set txt "Region"
-	    set r [EntryDialog "Text Region" "Enter Text:" 40 txt]
-	    if {$r == 1 && $txt != {}} {
-		append cmd " 0 text = \{\{$txt\}\}"
-	    } else {
-		return
-	    }
-	}
+	text {append cmd " 0 text = \{\{Region\}\}"}
 	ruler {append cmd " $x $y $ed(system) $ed(sky) $ed(system) $ed(dformat) ''"}
-	compass {append cmd " 15 $ed(system) $ed(sky) "}
+	compass {append cmd " 15 $ed(system) $ed(sky)"}
 	{circle point} -
 	{box point} -
 	{diamond point} -
@@ -666,9 +660,11 @@ proc MarkerCreateShape {which x y} {
 	{boxcircle point} {append cmd " $pmarker(point,size)"}
     }
     append cmd " color = $marker(color)"
+    append cmd " fill = $marker(fill)"
     append cmd " width = $marker(width)"
-    append cmd " font = \{\"$marker(font) $marker(font,size) $marker(font,weight) $marker(font,slant)\"\}"
     append cmd " dash = $marker(dash)"
+    append cmd " font = \{\"$marker(font) $marker(font,size) $marker(font,weight) $marker(font,slant)\"\}"
+
     append cmd " fixed = $marker(fixed)"
     append cmd " edit = $marker(edit)"
     append cmd " move = $marker(move)"
@@ -962,7 +958,7 @@ proc MarkerSelectAll {} {
     UpdateEditMenu
 }
 
-proc MarkerUnselectAll {} {
+proc MarkerSelectNone {} {
     global current
     
     if {$current(frame) != {}} {
@@ -982,24 +978,42 @@ proc MarkerSelectInvert {} {
     UpdateEditMenu
 }
 
-proc MarkerDelete {select} {
-    global pds9
+proc MarkerSelectFront {} {
+    global current
 
-    if {$pds9(confirm)} {
-	if {[tk_messageBox -type okcancel -icon question -message [msgcat::mc {Delete Regions?}]] != {ok}} {
-	    return 0
-	}
+    if {$current(frame) != {}} {
+	$current(frame) marker select first
+    }
+
+    UpdateEditMenu
+}
+
+proc MarkerSelectBack {} {
+    global current
+
+    if {$current(frame) != {}} {
+	$current(frame) marker select last
+    }
+
+    UpdateEditMenu
+}
+
+proc MarkerDeleteAll {} {
+    global current
+
+    if {$current(frame) != {}} {
+	$current(frame) marker delete
+	UpdateGroupDialog
     }
 
-    MarkerDeleteSelect $select
     return 1
 }
 
-proc MarkerDeleteSelect {select} {
+proc MarkerDeleteSelect {} {
     global current
     
     if {$current(frame) != {}} {
-	$current(frame) marker delete $select
+	$current(frame) marker delete select
 	UpdateGroupDialog
     }
 
@@ -1007,9 +1021,8 @@ proc MarkerDeleteSelect {select} {
 }
 
 proc MarkerDeleteLoad {} {
-    if {[MarkerDelete {}]} {
-	MarkerLoad
-    }
+    MarkerDeleteAll
+    MarkerLoad
 }
 
 proc MarkerColor {} {
@@ -1048,7 +1061,7 @@ proc MarkerFont {} {
     }
 }
 
-proc MarkerList {select} {
+proc MarkerListAll {} {
     global current
     global marker
 
@@ -1061,12 +1074,76 @@ proc MarkerList {select} {
 
     if {[MarkerSaveDialog [msgcat::mc {List Regions}]]} {
 	SimpleTextDialog markertxt [msgcat::mc {Region}] 80 20 insert top \
-	    [$current(frame) marker list $select \
+	    [$current(frame) marker list $marker(format) $marker(system) \
+		 $marker(sky) $marker(skyformat) $marker(strip)]
+    }
+}
+
+proc MarkerListSelect {} {
+    global current
+    global marker
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+
+    if {[MarkerSaveDialog [msgcat::mc {List Regions}]]} {
+	SimpleTextDialog markertxt [msgcat::mc {Region}] 80 20 insert top \
+	    [$current(frame) marker list select \
 		 $marker(format) $marker(system) \
 		 $marker(sky) $marker(skyformat) $marker(strip)]
     }
 }
 
+proc MarkerSaveAll {} {
+    global current
+    global marker
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+
+    set filename [SaveFileDialog markerfbox]
+    if {$filename == {}} {
+	return
+    }
+
+    if {[MarkerSaveDialog [msgcat::mc {Save Regions}]]} {
+	$current(frame) marker save "\{$filename\}" \
+	    $marker(format) $marker(system) $marker(sky) \
+	    $marker(skyformat) $marker(strip)
+    }
+}
+
+proc MarkerSaveSelect {} {
+    global current
+    global marker
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+
+    set filename [SaveFileDialog markerfbox]
+    if {$filename == {}} {
+	return
+    }
+
+    if {[MarkerSaveDialog [msgcat::mc {Save Regions}]]} {
+	$current(frame) marker save select "\{$filename\}" \
+	    $marker(format) $marker(system) $marker(sky) \
+	    $marker(skyformat) $marker(strip)
+    }
+}
+
 proc MarkerLoad {} {
     global ds9
     global current
@@ -1211,9 +1288,10 @@ proc MarkerLoadFile {filename which format sys sky} {
     UpdateGroupDialog
 }
 
-proc MarkerSave {select} {
+proc MarkerInfo {} {
     global current
     global marker
+    global pds9
 
     if {$current(frame) == {}} {
 	return
@@ -1221,39 +1299,15 @@ proc MarkerSave {select} {
     if {![$current(frame) has fits]} {
 	return
     }
-
-    set filename [SaveFileDialog markerfbox]
-    if {$filename == {}} {
-	return
-    }
-
-    if {[MarkerSaveDialog [msgcat::mc {Save Regions}]]} {
-	$current(frame) marker save $select "\{$filename\}" \
-	    $marker(format) $marker(system) $marker(sky) \
-	    $marker(skyformat) $marker(strip)
-    }
-}
-
-proc MarkerInfo {} {
-    global current
-    global marker
-    global pds9
-
-    if {$current(frame) != {}} {
-	set ll [$current(frame) get marker select]
-	if {$ll != {}} {
-	    set ii 0
-	    foreach dd $ll {
-		incr ii
-		if {$ii > $marker(maxdialog)} {
-		    return
-		}
-		MarkerDialog $current(frame) $dd
-	    }
-	} else {
-	    if {$pds9(confirm)} {
-		tk_messageBox -type ok -icon info -message [msgcat::mc {Please Select a Region}]
-	    }
+    
+    set ll [$current(frame) get marker select]
+    if {$ll != {}} {
+	foreach id $ll {
+	    MarkerDialog $current(frame) $id
+	}
+    } else {
+	if {$pds9(confirm)} {
+	    tk_messageBox -type ok -icon info -message [msgcat::mc {Please Select a Region}]
 	}
     }
 }
@@ -1387,6 +1441,7 @@ proc CompositeCreate {} {
 	append cmd " width = $marker(width)"
 	append cmd " font = \{\"$marker(font) $marker(font,size) $marker(font,weight) $marker(font,slant)\"\}"
 	append cmd " dash = $marker(dash)"
+	append cmd " fill = $marker(fill)"
 	append cmd " edit = $marker(edit)"
 	append cmd " move = $marker(move)"
 	append cmd " rotate = $marker(rotate)"
@@ -1487,7 +1542,7 @@ proc RegionCmdLoadFn {fn {all {0}}} {
 	$marker(load,format) $marker(load,system) $marker(load,sky)
 }
 
-proc RegionCmdSave {fn select} {
+proc RegionCmdSaveAll {fn} {
     global marker
     global current
 
@@ -1497,13 +1552,35 @@ proc RegionCmdSave {fn select} {
     if {![$current(frame) has fits]} {
 	return
     }
+    if {$fn == {}} {
+	return
+    }
 
-    $current(frame) marker save $select $fn $marker(format) \
+    $current(frame) marker save $fn $marker(format) \
 	$marker(system) $marker(sky) $marker(skyformat) $marker(strip)
     FileLast markerfbox $fn
 }
 
-proc RegionCmdList {select} {
+proc RegionCmdSaveSelect {fn} {
+    global marker
+    global current
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+    if {$fn == {}} {
+	return
+    }
+
+    $current(frame) marker save select $fn $marker(format) \
+	$marker(system) $marker(sky) $marker(skyformat) $marker(strip)
+    FileLast markerfbox $fn
+}
+
+proc RegionCmdListAll {} {
     global marker
     global current
 
@@ -1515,7 +1592,23 @@ proc RegionCmdList {select} {
     }
 
     SimpleTextDialog markertxt [msgcat::mc {Region}] 80 20 insert top \
-	[$current(frame) marker list $select $marker(format) $marker(system) \
+	[$current(frame) marker list $marker(format) $marker(system) \
+	     $marker(sky) $marker(skyformat) $marker(strip)]
+}
+
+proc RegionCmdListSelect {} {
+    global marker
+    global current
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+
+    SimpleTextDialog markertxt [msgcat::mc {Region}] 80 20 insert top \
+	[$current(frame) marker list select $marker(format) $marker(system) \
 	     $marker(sky) $marker(skyformat) $marker(strip)]
 }
 
@@ -1622,6 +1715,282 @@ proc RegionCmdCommand {cmd} {
     $current(frame) marker command $marker(format) "\{$cmd\}"
 }
 
+proc RegionCmdOpen {} {
+    global current
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+    
+    set ll [$current(frame) get marker select]
+    if {$ll != {}} {
+	foreach id $ll {
+	    MarkerDialog $current(frame) $id
+	}
+    }
+}
+
+proc RegionCmdClose {} {
+    global current
+    global imarker
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+
+    foreach id [$current(frame) get marker select] {
+	set varname ${imarker(prefix,dialog)}${id}${current(frame)}
+	global $varname
+	upvar #0 $varname var
+
+	if {[info exists var(proc,close)]} {
+	    eval "$var(proc,close) $varname"
+	}
+    }
+}
+
+proc RegionCmdAnalysis {task action} {
+    global current
+    global imarker
+
+    if {$current(frame) == {}} {
+	return
+    }
+    if {![$current(frame) has fits]} {
+	return
+    }
+
+    set frame $current(frame)
+
+    foreach id [$frame get marker select] {
+	set varname ${imarker(prefix,dialog)}${id}${frame}
+	global $varname
+	upvar #0 $varname var
+
+	switch $task {
+	    histogram {
+		# check for region type
+		switch [$frame get marker $id type] {
+		    circle -
+		    ellipse -
+		    box -
+		    polygon {}
+		    default {continue}
+		}
+		MarkerDialog $frame $id
+
+		switch $action {
+		    open {
+			set var(histogram) 1
+			MarkerAnalysisHistogramCmd $varname
+		    }
+		    close {
+			set var(histogram) 0
+			MarkerAnalysisHistogramCmd $varname
+			eval "$var(proc,close) $varname"
+		    }
+		    save {
+			set var(histogram) 1
+			MarkerAnalysisHistogramCmd $varname
+
+			set vvarname ${imarker(prefix,histogram)}${id}${frame}
+			upvar #0 $vvarname vvar
+			global $vvarname
+
+			set filename "${frame}.${id}.histogram.png"
+			PlotExport $vvarname $filename png
+		    }
+		}
+	    }
+	    panda {
+		# check for region type
+		switch [$frame get marker $id type] {
+		    panda -
+		    epanda -
+		    bpanda {}
+		    default {continue}
+		}
+		MarkerDialog $frame $id
+
+		switch $action {
+		    none -
+		    open {
+			set var(panda) 1
+			MarkerAnalysisPandaCmd $varname
+		    }
+		    close {
+			set var(panda) 0
+			MarkerAnalysisPandaCmd $varname
+			eval "$var(proc,close) $varname"
+		    }
+		    save {
+			set var(panda) 1
+			MarkerAnalysisPandaCmd $varname
+
+			set vvarname ${imarker(prefix,panda)}${id}${frame}
+			upvar #0 $vvarname vvar
+			global $vvarname
+
+			set filename "${frame}.${id}.panda.png"
+			PlotExport $vvarname $filename png
+		    }
+		}
+	    }
+	    plot2d {
+		# check for region type
+		switch [$frame get marker $id type] {
+		    line -
+		    projection -
+		    vector {}
+		    default {continue}
+		}
+		MarkerDialog $frame $id
+
+		switch $action {
+		    none -
+		    open {
+			set var(plot2d) 1
+			MarkerAnalysisPlot2dCmd $varname
+		    }
+		    close {
+			set var(plot2d) 0
+			MarkerAnalysisPlot2dCmd $varname
+			eval "$var(proc,close) $varname"
+		    }
+		    save {
+			set var(plot2d) 1
+			MarkerAnalysisPlot2dCmd $varname
+
+			set vvarname ${imarker(prefix,plot2d)}${id}${frame}
+			upvar #0 $vvarname vvar
+			global $vvarname
+
+			set filename "${frame}.${id}.plot2d.png"
+			PlotExport $vvarname $filename png
+		    }
+		}
+	    }
+	    plot3d {
+		# check for region type
+		switch [$frame get marker $id type] {
+		    circle -
+		    ellipse -
+		    box -
+		    polygon -
+		    point {}
+		    default {continue}
+		}
+		MarkerDialog $frame $id
+
+		switch $action {
+		    none -
+		    open {
+			set var(plot3d) 1
+			MarkerAnalysisPlot3dCmd $varname
+		    }
+		    close {
+			set var(plot3d) 0
+			MarkerAnalysisPlot3dCmd $varname
+			eval "$var(proc,close) $varname"
+		    }
+		    save {
+			set var(plot3d) 1
+			MarkerAnalysisPlot3dCmd $varname
+
+			set vvarname ${imarker(prefix,plot3d)}${id}${frame}
+			upvar #0 $vvarname vvar
+			global $vvarname
+
+			set filename "${frame}.${id}.plot3d.png"
+			PlotExport $vvarname $filename png
+		    }
+		}
+	    }
+	    radial {
+		# check for region type
+		switch [$frame get marker $id type] {
+		    annulus -
+		    ellipseannulus -
+		    boxannulus {}
+		    default {continue}
+		}
+		MarkerDialog $frame $id
+
+		switch $action {
+		    none -
+		    open {
+			set var(radial) 1
+			MarkerAnalysisRadialCmd $varname
+		    }
+		    close {
+			set var(radial) 0
+			MarkerAnalysisRadialCmd $varname
+			eval "$var(proc,close) $varname"
+		    }
+		    save {
+			set var(radial) 1
+			MarkerAnalysisRadialCmd $varname
+
+			set vvarname ${imarker(prefix,radial)}${id}${frame}
+			upvar #0 $vvarname vvar
+			global $vvarname
+
+			set filename "${frame}.${id}.radial.png"
+			PlotExport $vvarname $filename png
+		    }
+		}
+	    }
+	    stats {
+		# check for region type
+		switch [$frame get marker $id type] {
+		    circle -
+		    ellipse -
+		    box -
+		    polygon -
+		    annulus -
+		    ellipseannulus -
+		    boxannulus -
+		    panda -
+		    epanda -
+		    bpanda {}
+		    default {continue}
+		}
+		MarkerDialog $frame $id
+
+		switch $action {
+		    none -
+		    open {
+			set var(stats) 1
+			MarkerAnalysisStatsCmd $varname
+		    }
+		    close {
+			set var(stats) 0
+			MarkerAnalysisStatsCmd $varname
+			eval "$var(proc,close) $varname"
+		    }
+		    save {
+			set var(stats) 1
+			MarkerAnalysisStatsCmd $varname
+
+			set vvarname ${imarker(prefix,stats)}${id}${frame}
+			upvar #0 $vvarname vvar
+			global $vvarname
+
+			set filename "${frame}.${id}.stats.txt"
+			SimpleTextSaveFileName $vvarname $filename
+		    }
+		}
+	    }
+	}
+    }
+}
+
 proc ProcessSendRegionsCmd {proc id param sock fn} {
     global parse
     set parse(proc) $proc
