@@ -63,11 +63,11 @@ proc ZoomMainMenu {} {
     $ds9(mb).zoom add radiobutton -label "270 [msgcat::mc {Degrees}]" \
 	-variable current(rotate) -value 270 -command ChangeRotate
     $ds9(mb).zoom add separator
-    $ds9(mb).zoom add command -label "[msgcat::mc {Crop Parameters}]..." \
+    $ds9(mb).zoom add command -label [msgcat::mc {Crop Parameters}] \
 	-command CropDialog
     $ds9(mb).zoom add separator
     $ds9(mb).zoom add command \
-	-label "[msgcat::mc {Pan Zoom Rotate Parameters}]..." \
+	-label [msgcat::mc {Pan Zoom Rotate Parameters}] \
 	-command PanZoomDialog
 
     bind $ds9(top) <<ZoomIn>> [list Zoom 2 2]
@@ -212,7 +212,7 @@ proc CreateButtonsZoom {} {
     ButtonButton $ds9(buttons).zoom.center \
 	[string tolower [msgcat::mc {Center}]] CenterCurrentFrame
     CheckButton $ds9(buttons).zoom.align \
-	[msgcat::mc {Align}] current(align) AlignWCSFrame
+	[msgcat::mc {Align}] current align AlignWCSFrame
 
     ButtonButton $ds9(buttons).zoom.in \
 	[string tolower [msgcat::mc {Zoom In}]] {Zoom 2 2}
@@ -222,49 +222,56 @@ proc CreateButtonsZoom {} {
 	[string tolower [msgcat::mc {Zoom Fit}]] ZoomToFit
     RadioButton $ds9(buttons).zoom.i32 \
  	"[string tolower [msgcat::mc {Zoom}]] 1/32" \
-	current(zoom) {0.03125 0.03125} ChangeZoom
+	current zoom {0.03125 0.03125} ChangeZoom
     RadioButton $ds9(buttons).zoom.i16 \
 	"[string tolower [msgcat::mc {Zoom}]] 1/16" \
-	current(zoom) {0.0625 0.0625} ChangeZoom
+	current zoom {0.0625 0.0625} ChangeZoom
     RadioButton $ds9(buttons).zoom.i8 \
 	"[string tolower [msgcat::mc {Zoom}]] 1/8" \
-	current(zoom) {0.125 0.125} ChangeZoom
+	current zoom {0.125 0.125} ChangeZoom
     RadioButton $ds9(buttons).zoom.i4 \
 	"[string tolower [msgcat::mc {Zoom}]] 1/4" \
-	current(zoom) {0.25 0.25} ChangeZoom
+	current zoom {0.25 0.25} ChangeZoom
     RadioButton $ds9(buttons).zoom.i2 \
 	"[string tolower [msgcat::mc {Zoom}]] 1/2" \
-	current(zoom) {0.5 0.5} ChangeZoom
+	current zoom {0.5 0.5} ChangeZoom
     RadioButton $ds9(buttons).zoom.1 \
 	"[string tolower [msgcat::mc {Zoom}]] 1" \
-	current(zoom) {1 1} ChangeZoom
+	current zoom {1 1} ChangeZoom
     RadioButton $ds9(buttons).zoom.2 \
 	"[string tolower [msgcat::mc {Zoom}]] 2" \
-	current(zoom) {2 2} ChangeZoom
+	current zoom {2 2} ChangeZoom
     RadioButton $ds9(buttons).zoom.4 \
 	"[string tolower [msgcat::mc {Zoom}]] 4" \
-	current(zoom) {4 4} ChangeZoom
+	current zoom {4 4} ChangeZoom
     RadioButton $ds9(buttons).zoom.8 \
 	"[string tolower [msgcat::mc {Zoom}]] 8" \
-	current(zoom) {8 8} ChangeZoom
+	current zoom {8 8} ChangeZoom
     RadioButton $ds9(buttons).zoom.16 \
 	"[string tolower [msgcat::mc {Zoom}]] 16" \
-	current(zoom) {16 16} ChangeZoom
+	current zoom {16 16} ChangeZoom
     RadioButton $ds9(buttons).zoom.32 \
  	"[string tolower [msgcat::mc {Zoom}]] 32" \
- 	current(zoom) {32 32} ChangeZoom
+ 	current zoom {32 32} ChangeZoom
 
     RadioButton $ds9(buttons).zoom.none \
 	[string tolower [msgcat::mc {None}]] \
-	current(orient) none ChangeOrient
-    RadioButton $ds9(buttons).zoom.x {x} current(orient) x ChangeOrient
-    RadioButton $ds9(buttons).zoom.y {y} current(orient) y ChangeOrient
-    RadioButton $ds9(buttons).zoom.xy {xy} current(orient) xy ChangeOrient
+	current orient none ChangeOrient
+    RadioButton $ds9(buttons).zoom.x {x} \
+	current orient x ChangeOrient
+    RadioButton $ds9(buttons).zoom.y {y} \
+	current orient y ChangeOrient
+    RadioButton $ds9(buttons).zoom.xy {xy} \
+	current orient xy ChangeOrient
 
-    RadioButton $ds9(buttons).zoom.0 {0} current(rotate) 0 ChangeRotate
-    RadioButton $ds9(buttons).zoom.90 {90} current(rotate) 90 ChangeRotate
-    RadioButton $ds9(buttons).zoom.180 {180} current(rotate) 180 ChangeRotate
-    RadioButton $ds9(buttons).zoom.270 {270} current(rotate) 270 ChangeRotate
+    RadioButton $ds9(buttons).zoom.0 {0} \
+	current rotate 0 ChangeRotate
+    RadioButton $ds9(buttons).zoom.90 {90} \
+	current rotate 90 ChangeRotate
+    RadioButton $ds9(buttons).zoom.180 {180} \
+	current rotate 180 ChangeRotate
+    RadioButton $ds9(buttons).zoom.270 {270} \
+	current rotate 270 ChangeRotate
 
     ButtonButton $ds9(buttons).zoom.crop \
 	[string tolower [msgcat::mc {Crop}]] CropDialog
@@ -366,10 +373,10 @@ proc PrefsDialogButtonbarZoom {f} {
     $m add checkbutton -label "270 [msgcat::mc {Degrees}]" \
 	-variable pbuttons(zoom,270) -command {UpdateButtons buttons(zoom)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Crop Parameters}]..." \
+    $m add checkbutton -label [msgcat::mc {Crop Parameters}] \
 	-variable pbuttons(zoom,crop) -command {UpdateButtons buttons(zoom)}
     $m add separator
-    $m add checkbutton -label "[msgcat::mc {Pan Zoom Rotate Parameters}]..." \
+    $m add checkbutton -label [msgcat::mc {Pan Zoom Rotate Parameters}] \
 	-variable pbuttons(zoom,params) -command {UpdateButtons buttons(zoom)}
 }
 
