@@ -46,7 +46,7 @@ proc PlotLineMenus {varname} {
     $var(mb).dataline add checkbutton -label [msgcat::mc {Show}] \
 	-variable ${varname}(graph,ds,show) \
 	-command [list PlotLineUpdateElement $varname]
-    $var(mb).dataline add command -label "[msgcat::mc {Name}]..." \
+    $var(mb).dataline add command -label [msgcat::mc {Name}] \
 	-command [list DatasetNameDialog $varname]
     $var(mb).dataline add separator
     $var(mb).dataline add cascade -label [msgcat::mc {Color}] \
@@ -116,8 +116,8 @@ proc PlotLineMenus {varname} {
 
     ColorMenu $var(mb).dataline.error.color $varname graph,ds,error,color \
 	[list PlotLineUpdateElement $varname]
-    WidthDashMenu $var(mb).dataline.error.width $varname \
-	graph,ds,error,width {} [list PlotLineUpdateElement $varname] {}
+    WidthMenu $var(mb).dataline.error.width $varname \
+	graph,ds,error,width [list PlotLineUpdateElement $varname]
 }
 
 proc PlotLineWidthMenu {w varname cmd} {
@@ -283,6 +283,16 @@ proc PlotLineUpdateElement {varname} {
 	-errorbarcolor $errorcolor \
 	-errorbarwidth $var(graph,ds,error,width) \
 	-errorbarcap $cap
+
+    $var(graph) pen configure active \
+	-color red \
+	-symbol $var(graph,ds,line,shape,symbol) \
+	-linewidth 0 \
+	-pixels 5 \
+	-showerrorbars $show \
+	-errorbarcolor $errorcolor \
+	-errorbarwidth $var(graph,ds,error,width) \
+	-errorbarcap $cap
 }
 
 
@@ -324,6 +334,52 @@ proc PlotPrefsLine {w} {
     grid $f.tsmooth $f.smooth -padx 2 -pady 2 -sticky w
 }
 
+proc PlotLineButton {varname cc nn xx yy} {
+    upvar #0 $varname var
+    global $varname
+
+    if {[llength $var($cc,dss)] == 0} {
+	return
+    }
+
+    if {$var(callback) == {}} {
+	return
+    }
+
+    set rr [$var($cc,graph) element closest $xx $yy]
+    set elem [lindex $rr 1]
+    set row [lindex $rr 3]
+
+    if {$elem != {}} {
+	if {$row != {}} {
+	    $var($cc,graph) element deactivate $elem
+	    $var($cc,graph) element activate $elem $row
+	    # rows start at 1
+	    eval "$var(callback) [expr $row+1] $cc"
+	} else {
+	    $var($cc,graph) element deactivate $elem
+	    eval "$var(callback) {} $cc"
+	}
+    }
+}
+
+proc PlotLineHighliteElement {varname cc nn rowlist} {
+    upvar #0 $varname var
+    global $varname
+
+    if {[llength $var($cc,dss)] == 0} {
+	return
+    }
+
+    if {$var($cc,$nn,show)} {
+	$var($cc,graph) element deactivate $nn
+	if {$rowlist != {}} {
+	    # can have multiple rows
+	    eval "$var($cc,graph) element activate $nn $rowlist"
+	}
+    }
+}
+
 proc PlotGUILine {varname w} {
     upvar #0 $varname var
     global $varname
