@@ -47,7 +47,7 @@ proc PlotScatterMenus {varname} {
     $var(mb).datascatter add checkbutton -label [msgcat::mc {Show}] \
 	-variable ${varname}(graph,ds,show) \
 	-command [list PlotScatterUpdateElement $varname]
-    $var(mb).datascatter add command -label "[msgcat::mc {Name}]..." \
+    $var(mb).datascatter add command -label [msgcat::mc {Name}] \
 	-command [list DatasetNameDialog $varname]
     $var(mb).datascatter add separator
     $var(mb).datascatter add cascade -label [msgcat::mc {Shape}] \
@@ -90,8 +90,8 @@ proc PlotScatterMenus {varname} {
 
     ColorMenu $var(mb).datascatter.error.color $varname \
 	graph,ds,error,color [list PlotScatterUpdateElement $varname]
-    WidthDashMenu $var(mb).datascatter.error.width $varname \
-	graph,ds,error,width {} [list PlotScatterUpdateElement $varname] {}
+    WidthMenu $var(mb).datascatter.error.width $varname \
+	graph,ds,error,width [list PlotScatterUpdateElement $varname]
 }
 
 proc PlotScatterShapeMenu {w var cmd} {
