@@ -97,6 +97,19 @@ proc ChangeScaleMode {} {
     }
 }
 
+proc ChangeScaleModeDialog {} {
+    global scale
+
+    set mm $scale(mode)
+    if {![string is double $mm]} {
+	set mm 100
+    }
+    if {[EntryDialog [msgcat::mc {Scale Mode}] [msgcat::mc {Percent}] 10 mm]} {
+	set scale(mode) $mm
+	ChangeScaleMode
+    }
+}
+
 proc ChangeScaleLimit {} {
     global current
     global scale
@@ -238,7 +251,7 @@ proc ScaleDialog {} {
     $mb.scale add radiobutton -label [msgcat::mc {Histogram Equalization}] \
 	-variable scale(type) -command ChangeScale -value histequ
     $mb.scale add separator
-    $mb.scale add command -label "[msgcat::mc {Log Exponent}]..." \
+    $mb.scale add command -label [msgcat::mc {Log Exponent}] \
 	-command ScaleLogDialog
 
     ThemeMenu $mb.limit
@@ -268,6 +281,9 @@ proc ScaleDialog {} {
 	-variable scale(mode) -command ChangeScaleMode -value zmax
     $mb.limit add radiobutton -label [msgcat::mc {User}] \
 	-variable scale(mode) -command ChangeScaleMode -value user
+    $mb.limit add separator
+    $mb.limit add command -label [msgcat::mc {Other}] \
+	-command ChangeScaleModeDialog
 
     ThemeMenu $mb.scope 
     $mb.scope add radiobutton -label [msgcat::mc {Global}] \
@@ -285,14 +301,14 @@ proc ScaleDialog {} {
     $mb.minmax add radiobutton -label {IRAF-MIN IRAF-MAX} \
 	-variable minmax(mode) -value irafmin -command ChangeMinMax
     $mb.minmax add separator
-    $mb.minmax add command -label "[msgcat::mc {Sample Parameters}]..." \
+    $mb.minmax add command -label [msgcat::mc {Sample Parameters}] \
 	-command MinMaxDialog
 
     ThemeMenu $mb.param 
     $mb.param add checkbutton -label "[msgcat::mc {Use}] DATASEC" \
 	-variable scale(datasec) -command ChangeDATASEC
     $mb.param add separator
-    $mb.param add command -label {ZScale...} -command ZScaleDialog
+    $mb.param add command -label {ZScale} -command ZScaleDialog
 
     ThemeMenu $mb.graph 
     $mb.graph add radiobutton -label [msgcat::mc {Linear}] \
@@ -609,19 +625,19 @@ proc ScaleXAxisDialog {} {
 
     switch -- $scale(xaxis) { 
 	full {
-	    set width [expr abs(1.0*($dscale(minmax)-$dscale(minmin))/ \
-				    [$dscale(xdata) length])]
+	    set diff \
+		[expr ($dscale(minmax)-$dscale(minmin))/[$dscale(xdata) length]]
 
-	    $dscale(hist) xaxis configure \
-		-min [expr $dscale(minmin)-$width] \
-		-max [expr $dscale(minmax)+$width]
+	    if {[expr abs($diff)] > 0} {
+		set a [expr $dscale(minmin)-$diff]
+		set b [expr $dscale(minmax)+$diff]
+		$dscale(hist) xaxis configure -min $a -max $b
+	    }
 	}
 	current {
-	    set width [expr abs(1.0*($dscale(max)-$dscale(min))/ \
-				    [$dscale(xdata) length])]
+	    set diff [expr $dscale(max)-$dscale(min)]
 
-	    if {[expr abs($dscale(max)-$dscale(min)) > 0]} {
-		set diff [expr $dscale(max)-$dscale(min)]
+	    if {[expr abs($diff)] > 0} {
 		set per .10
 		set a [expr $dscale(min)-($diff*$per)]
 		set b [expr $dscale(max)+($diff*$per)]
@@ -777,6 +793,8 @@ proc MatchScale {which} {
 		[list $ff clip minmax $mmsample $mmmode]
 	    RGBEvalLock rgb(lock,scale) $ff \
 		[list $ff clip zscale $zscontrast $zssample $zsline]
+
+	    UpdateColormapLevelFrame $ff
 	}
     }
 }
@@ -808,6 +826,8 @@ proc MatchScaleLimits {which} {
 	    [list $ff clip minmax $mmsample $mmmode]
 	RGBEvalLock rgb(lock,scalelimits) $ff \
 	    [list $ff clip zscale $zscontrast $zssample $zsline]
+
+	UpdateColormapLevelFrame $ff
     }
 }
 
