@@ -150,8 +150,21 @@ proc ::tk::dialog::file:: {type args} {
     # this can hang the entire application.  Therefore we only make the dialog
     # transient if the parent is viewable.
 
-    if {[winfo viewable [winfo toplevel $data(-parent)]]} {
-	wm transient $w $data(-parent)
+    if {[winfo viewable [winfo toplevel $data(-parent)]] } {
+	global tcl_platform
+	switch $tcl_platform(os) {
+	    Darwin {
+		set vv [lindex [split $tcl_platform(osVersion) {.}] 0]
+		if {$vv > 21} {
+		    # ventura
+		    raise $w $data(-parent)
+		} else {
+		    # monterey and previous
+		    wm transient $w $data(-parent)
+		}
+	    }
+	    default {wm transient $w $data(-parent)}
+	}
     }
 
     # Add traces on the selectPath variable
