@@ -199,6 +199,11 @@ proc CreateXPA {} {
 	{} {} {} \
 	XPARcvdExport {} "fillbuf=false"
  
+    xpacmdadd $xpa fade \
+	{} \
+	XPASendFade {} {} \
+	XPARcvdFade {} "fillbuf=false"
+
     xpacmdadd $xpa file \
 	{} \
 	XPASendFile {} {} \
@@ -264,6 +269,11 @@ proc CreateXPA {} {
 	XPASendIIS {} {} \
 	XPARcvdIIS {} "fillbuf=false"
 
+    xpacmdadd $xpa illustrate \
+	{} \
+	XPASendIllustrate {} {} \
+	XPARcvdIllustrate {} "fillbuf=false"
+
     # backward compatibility
     xpacmdadd $xpa imexam \
 	{} \
@@ -1033,6 +1043,19 @@ proc XPARcvdExport {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendFade {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendFadeCmd xpasetbuf $xpa $param}
+    XPACatchError $xpa
+}
+
+proc XPARcvdFade {xpa cdata param buf len} {
+    XPADebug "XPARcvdFade" $param
+    InitError xpa
+    catch {set i 0; ProcessFadeCmd param i}
+    XPACatchError $xpa
+}
+
 proc XPASendFile {xpa cdata param} {
     InitError xpa
     catch {ProcessSendFileCmd xpasetbuf $xpa $param}
@@ -1204,6 +1227,19 @@ proc XPARcvdIIS {xpa cdata param buf len} {
     XPACatchError $xpa
 }
 
+proc XPASendIllustrate {xpa cdata param} {
+    InitError xpa
+    catch {ProcessSendIllustrateCmd xpasetbuf $xpa $param {} {}}
+    XPACatchError $xpa
+}
+
+proc XPARcvdIllustrate {xpa cdata param buf len} {
+    XPADebug "XPARcvdIllustrate" $param
+    InitError xpa
+    catch {set i 0; ProcessIllustrateCmd param i [xparec $xpa datachan] {}}
+    XPACatchError $xpa
+}
+
 proc XPASendJPEG {xpa cdata param} {
     InitError xpa
     catch {
