@@ -36,27 +36,30 @@ set WCSX_ 291
 set WCSY_ 292
 set WCSZ_ 293
 set STRING_ 294
-set BLUE_ 295
-set BUTTONS_ 296
-set COLORBAR_ 297
-set COLORBARNUMERICS_ 298
-set FILENAME_ 299
-set FRAME_ 300
-set GRAPH_ 301
-set GREEN_ 302
-set HORIZONTAL_ 303
-set HORZGRAPH_ 304
-set INFO_ 305
-set KEYVALUE_ 306
-set KEYWORD_ 307
-set LAYOUT_ 308
-set LOWHIGH_ 309
-set MAGNIFIER_ 310
-set MINMAX_ 311
-set MULTI_ 312
-set OBJECT_ 313
-set PANNER_ 314
-set RED_ 315
-set UNITS_ 316
-set VERTICAL_ 317
-set VERTGRAPH_ 318
+set ADVANCED_ 295
+set BASIC_ 296
+set BLUE_ 297
+set BUTTONS_ 298
+set COLORBAR_ 299
+set COLORBARNUMERICS_ 300
+set FILENAME_ 301
+set FRAME_ 302
+set GRAPH_ 303
+set GREEN_ 304
+set HORIZONTAL_ 305
+set HORZGRAPH_ 306
+set ICONS_ 307
+set INFO_ 308
+set KEYVALUE_ 309
+set KEYWORD_ 310
+set LAYOUT_ 311
+set LOWHIGH_ 312
+set MAGNIFIER_ 313
+set MINMAX_ 314
+set MULTI_ 315
+set OBJECT_ 316
+set PANNER_ 317
+set RED_ 318
+set UNITS_ 319
+set VERTICAL_ 320
+set VERTGRAPH_ 321
