@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -43,10 +43,12 @@ public:
   void getColormapCmd();
   void getColormapNameCmd(int);
   void getColormapFileNameCmd(int);
+  void getColormapFileNameCmd(const char*);
   void getContrastCmd();
   void getCurrentFileNameCmd();
   void getCurrentIDCmd();
   void getCurrentNameCmd();
+  void getTypeCmd();
   void setColorbarCmd(float, float, float, float, float, float, int);
   void getRGBChannelCmd();
   void setRGBChannelCmd(const char*);
