@@ -130,7 +130,7 @@ public:
 		SHARE, SSHARE, SOCKET, SOCKETGZ, VAR, HIST, POST, PHOTO};
   enum MosaicType {NOMOSAIC, IRAF, WCSMOSAIC};
   enum LayerType {IMG, MASK};
-  enum CutMethod {SUM,AVERAGE};
+  enum CutMethod {SUM,AVERAGE,MEDIAN};
 
  private:
   InverseScale* inverseScale;
@@ -467,8 +467,8 @@ public:
   void updateCBMarkers(List<Marker>*);
   virtual void updateColorScale() =0;
   virtual void updateGCs();
-  void updateMagnifier();
-  void updateMagnifier(const Vector&);
+  virtual void updateMagnifier();
+  virtual void updateMagnifier(const Vector&);
 
   virtual void updateMatrices();
   virtual void updateMagnifierMatrices();
@@ -504,7 +504,6 @@ public:
   double* xmlDistance(FitsImage*, const char*, int, Coord::CoordSystem, Coord::DistFormat);
   Vector* xmlDistance(FitsImage*, const char*, const char*, int, Coord::CoordSystem, Coord::DistFormat);
   void ximageToPixmap(Pixmap, XImage*, Coord::InternalSystem);
-  virtual void ximageToPixmapMagnifier();
 
   Vector zoom() {return zoom_;}
 
@@ -655,14 +654,14 @@ public:
 
   // Colormap Commands
   void colorbarTagCmd(const char*);
-  virtual void colormapCmd(int, float, float, int, unsigned char*, int) {}
+  virtual void colormapCmd(int, float, float, int, int) {}
   virtual void colormapCmd(float, float, float, float, float, float, int,
-			   unsigned char*, int) {}
+			   int) {}
   virtual void colormapBeginCmd() {}
   virtual void colormapEndCmd() {}
-  virtual void colormapMotionCmd(int, float, float, int, unsigned char*, int) {}
+  virtual void colormapMotionCmd(int, float, float, int, int) {}
   virtual void colormapMotionCmd(float, float, float, float, float, float, int,
-				 unsigned char*, int) {}
+				 int) {}
   virtual void getColorbarCmd() =0;
   void getColorbarTagCmd();
 
@@ -751,6 +750,10 @@ public:
 			Coord::SkyFrame, const Vector&, char*);
   void getDataValuesCmd(const Vector&, Coord::InternalSystem, const Vector&);
 
+  // Fade Commands
+  virtual void fadeCmd(float) {}
+  virtual void fadeClearCmd() {}
+
   // Fits Commands
   void getBitpixCmd();
   void getFitsNAxesCmd();
@@ -1009,13 +1012,13 @@ public:
   virtual void iisCmd(int, int) {}
   virtual void iisCursorModeCmd(int) {}
   virtual void iisEraseCmd() {}
-  virtual void iisGetCmd(char*, int, int, int, int) {}
+  virtual void iisGetCmd(int, int, int, int) {}
   virtual void iisGetCursorCmd() {}
   virtual void iisGetFileNameCmd() {}
   virtual void iisGetFileNameCmd(int) {}
   virtual void iisGetFileNameCmd(const Vector&) {}
   virtual void iisMessageCmd(const char*) {}
-  virtual void iisSetCmd(const char*, int, int, int, int) {}
+  virtual void iisSetCmd(int, int, int, int) {}
   virtual void iisSetCursorCmd(const Vector&, Coord::InternalSystem) {}
   virtual void iisSetCursorCmd(const Vector&, Coord::CoordSystem) {}
   virtual void iisSetFileNameCmd(const char*) {}
@@ -1025,8 +1028,8 @@ public:
   void hasIISCmd();
 
   // Info Commands
-  void getInfoCmd(char*);
-  virtual void getInfoCmd(const Vector&, Coord::InternalSystem, char*) =0;
+  void getInfoCmd(char*, Base::FileNameType);
+  virtual void getInfoCmd(const Vector&, Coord::InternalSystem, char*, Base::FileNameType) =0;
   void getInfoClipCmd();
   void getValueCmd(const Vector&, Coord::InternalSystem);
 
@@ -1048,28 +1051,28 @@ public:
   // Marker Commands
   // Basic Regions
   void createCircleCmd(const Vector&, 
-		       double, int,
+		       double,
 		       const char*, int*, int, const char*, 
 		       const char*, unsigned short, const char*,
 		       const List<Tag>&, const List<CallBack>& cb);
   void createEllipseCmd(const Vector&, 
 			const Vector&, 
-			double, int,
+			double,
 			const char*, int*, int, const char*, 
 			const char*, unsigned short, const char*,
 			const List<Tag>&, const List<CallBack>& cb);
   void createBoxCmd(const Vector&, 
 		    const Vector&, 
-		    double, int,
+		    double,
 		    const char*, int*, int, const char*, 
 		    const char*, unsigned short, const char*,
 		    const List<Tag>&, const List<CallBack>& cb);
   void createPolygonCmd(const Vector&, 
-			const Vector&, int,
+			const Vector&,
 			const char*, int*, int, const char*, 
 			const char*, unsigned short, const char*,
 			const List<Tag>&, const List<CallBack>& cb);
-  void createPolygonCmd(const List<Vertex>&, int,
+  void createPolygonCmd(const List<Vertex>&,
 			const char*, int*, int, const char*, 
 			const char*, unsigned short, const char*,
 			const List<Tag>&, const List<CallBack>& cb);
@@ -1245,7 +1248,6 @@ public:
   void getMarkerAngleCmd(int);
   void getMarkerAngleCmd(int, Coord::CoordSystem, Coord::SkyFrame);
   void getMarkerAnnulusRadiusCmd(int, Coord::CoordSystem, Coord::DistFormat);
-  void getMarkerBoxFillCmd(int);
   void getMarkerBoxAnnulusRadiusCmd(int, Coord::CoordSystem, Coord::DistFormat);
   void getMarkerBoxRadiusCmd(int, Coord::CoordSystem, Coord::DistFormat);
   void getMarkerBpandaAnglesCmd(int);
@@ -1256,7 +1258,6 @@ public:
   void getMarkerCentroidRadiusCmd();
   void getMarkerCentroidIterationCmd();
   void getMarkerCentroidOptionCmd();
-  void getMarkerCircleFillCmd(int);
   void getMarkerCircleRadiusCmd(int, Coord::CoordSystem, Coord::DistFormat);
   void getMarkerColorCmd();
   void getMarkerColorCmd(const char*);
@@ -1269,13 +1270,17 @@ public:
   void getMarkerCpandaAnglesCmd(int);
   void getMarkerCpandaAnglesCmd(int, Coord::CoordSystem, Coord::SkyFrame);
   void getMarkerCpandaRadiusCmd(int, Coord::CoordSystem, Coord::DistFormat);
-  void getMarkerEllipseFillCmd(int);
   void getMarkerEllipseRadiusCmd(int, Coord::CoordSystem, Coord::DistFormat);
   void getMarkerEllipseAnnulusRadiusCmd(int, Coord::CoordSystem,Coord::DistFormat);
   void getMarkerEpandaAnglesCmd(int);
   void getMarkerEpandaAnglesCmd(int, Coord::CoordSystem, Coord::SkyFrame);
   void getMarkerEpandaRadiusCmd(int, Coord::CoordSystem, Coord::DistFormat);
   void getMarkerEpsilonCmd();
+
+  void getMarkerFillCmd();
+  void getMarkerFillCmd(const char*);
+  void getMarkerFillCmd(int);
+
   void getMarkerFontCmd();
   void getMarkerFontCmd(const char*);
   void getMarkerFontCmd(int);
@@ -1291,7 +1296,6 @@ public:
   void getMarkerNumberCmd();
   void getMarkerPointShapeCmd(int);
   void getMarkerPointSizeCmd(int);
-  void getMarkerPolygonFillCmd(int);
   void getMarkerPolygonSegmentCmd(const Vector&);
   void getMarkerPreserveCmd();
   void getMarkerProjectionPointsCmd(int, Coord::CoordSystem, Coord::SkyFrame, Coord::SkyFormat);
@@ -1349,7 +1353,6 @@ public:
   void markerBackCmd();
   void markerBackCmd(const char*);
   void markerBackCmd(int);
-  void markerBoxFillCmd(int, int);
   void markerBoxAnnulusRadiusCmd(int, const Vector&, const Vector&, int, 
 				 Coord::CoordSystem, Coord::DistFormat);
   void markerBoxAnnulusRadiusCmd(int, const char*, Coord::CoordSystem, Coord::DistFormat);
@@ -1375,7 +1378,6 @@ public:
   void markerCentroidAutoCmd(int);
   void markerCentroidRadiusCmd(float);
   void markerCentroidIterationCmd(int);
-  void markerCircleFillCmd(int, int);
   void markerCircleRadiusCmd(int, double, Coord::CoordSystem, Coord::DistFormat);
   void markerColorCmd(const char*);
   void markerColorCmd(const char*, const char*);
@@ -1415,7 +1417,6 @@ public:
   void markerEditBeginCmd(const Vector&, int);
   void markerEditMotionCmd(const Vector&, int);
   void markerEditEndCmd();
-  void markerEllipseFillCmd(int, int);
   void markerEllipseRadiusCmd(int, const Vector&,
 			      Coord::CoordSystem, Coord::DistFormat);
   void markerEllipseAnnulusRadiusCmd(int, const Vector&, const Vector&, int, 
@@ -1437,6 +1438,10 @@ public:
 			   Coord::CoordSystem, Coord::DistFormat);
   void markerEpsilonCmd(int ee) {markerEpsilon = ee;}
 
+  void markerFillCmd(int);
+  void markerFillCmd(const char*, int);
+  void markerFillCmd(int, int);
+
   void markerFontCmd(const char*);
   void markerFontCmd(const char*, const char*);
   void markerFontCmd(int, const char*);
@@ -1484,7 +1489,6 @@ public:
   void markerPasteCmd(Coord::CoordSystem);
   void markerPointShapeCmd(int, Point::PointShape);
   void markerPointSizeCmd(int, int);
-  void markerPolygonFillCmd(int, int);
   void markerPolygonCreateVertexCmd(int, int, const Vector&);
   void markerPolygonDeleteVertexCmd(int, int);
   void markerPolygonResetCmd(int, const Vector&, Coord::CoordSystem, Coord::DistFormat);
@@ -1513,6 +1517,8 @@ public:
   void markerSegmentDeleteVertexCmd(int, int);
   void markerSegmentResetCmd(int, const Vector&, Coord::CoordSystem, Coord::DistFormat);
   void markerSelectAllCmd();
+  void markerSelectFirstCmd();
+  void markerSelectLastCmd();
   void markerSelectCmd(int); // not used
   void markerSelectCmd(const char*);
   void markerSelectToggleCmd();
@@ -1603,7 +1609,7 @@ public:
   void wcsAlignCmd(int);
   // used by backup
   void wcsAlignCmd(int, Coord::CoordSystem, Coord::SkyFrame);
-  void wcsAlignCmd(int, FitsImage*, Coord::CoordSystem, Coord::SkyFrame);
+  void wcsAlign2Cmd(int, Coord::CoordSystem, Coord::SkyFrame);
   void zoomCmd(const Vector&);
   void zoomToCmd(const Vector&);
   virtual void zoomAboutCmd(const Vector&, const Vector&) =0;
