@@ -1,4 +1,4 @@
-// Copyright (C) 1999-2018
+// Copyright (C) 1999-2021
 // Smithsonian Astrophysical Observatory, Cambridge, MA, USA
 // For conditions of distribution and use, see copyright notice in "copyright"
 
@@ -14,11 +14,7 @@ protected:
 
   void renderXInclude(Drawable, Coord::InternalSystem, RenderMode) {}
 
-  void renderPSInclude(int) {}
-
-#ifdef MAC_OSX_TK
-  void renderMACOSXInclude() {}
-#endif
+  void renderPSInclude(PSColorSpace) {}
 
 #ifdef __WIN32
   void renderWIN32Include() {}
