@@ -122,6 +122,8 @@ class Frame3dBase : public Base {
   void updatePannerMatrices();
   void updateMatrices();
   void updatePanner();
+  void updateMagnifier();
+  void updateMagnifier(const Vector&);
 
   void x11Ants3d();
   void x11Line(Vector, Vector, int, GC, Pixmap);
@@ -158,7 +160,7 @@ class Frame3dBase : public Base {
   void clipScopeCmd(FrScale::ClipScope) {} // scope is always GLOBAL
 
   // Info Commands
-  void getInfoCmd(const Vector&, Coord::InternalSystem, char*);
+  void getInfoCmd(const Vector&, Coord::InternalSystem, char*, Base::FileNameType type);
 
   // Coordinate Commands
   void getCursorCmd(Coord::InternalSystem);
