@@ -30,7 +30,8 @@ public:
 
   void crosshairCmd(int);
   void getBBoxCmd();
-  void updateCmd(void*);
+  void updateCmd();
+  void clearCmd();
 };
 
 #endif
